@@ -179,7 +179,7 @@ pages = {
           <b>You didn't specify what account to activate.</b>
         </p></font>
         <p>
-          This wiki page is used for activateing new wiki accounts.
+          This wiki page is used for activating new wiki accounts.
           As you are not doing that there is nothing to see here.
         </p>
       </font>
@@ -194,7 +194,7 @@ pages = {
           Perhaps:
           <ul>
           <li>it never was created,</li>
-          <li>or its been responded to,</li>
+          <li>or it has been responded to,</li>
           <li>or it has expired (they only last a week).</li>
           </ul>
         </p>
@@ -211,7 +211,7 @@ pages = {
         <p>
           Either you are trying to hack me, or the the link you followed is
           from an earlier account creation attempt that has been cancelled.
-          The latter explaination seems unlikely.
+          The latter explanation seems unlikely.
         </p>
       </font>
     """,
@@ -464,7 +464,7 @@ def superEmailActivation(request, form):
 # the defaults where there aren't any.
 #
 ACTIVATED_EMAIL_TEXT = """
-Congradulations %(user.name)s!
+Congratulations %(user.name)s!
 
 Your account on the %(sitename)s has been
 activated.  You can now login at this url:
